==> adapters-2023.04.24-692.jar: com/vadelabs/adapter_rest/interface.clj <==
(ns com.vadelabs.adapter-rest.interface
  (:require
   [com.vadelabs.utils-core.interface :as uc]))

(def adapter
  {:adapter/id (uc/uuid ::adapter)
   :adapter/nspace :rest
   :adapter/type :adapter.type/rest
   :adapter/qualify-attributes false
   :adapter/config {}})

(def datasources
  [{:datasource/id (uc/uuid ::datasource)
    :datasource/display-name "REST"
    :datasource/description "Adapter to integrate REST API"
    :datasource/slug "rest"
    :datasource/icon ""
    :datasource/preview ""
    :datasource/adapter adapter
    :datasource/attributes []
    :datasource/actions []
    :datasource/categories []
    :datasource/collections []}])

;; (defmethod ac/connect :adapter.type/rest
;;   [genv {:adapter/keys [type id]}]
;;   (let [aenv (get-in genv [type id])
;;         http-instance (delay (rc/http-instance aenv))]
;;     (-> genv
;;       (assoc-in [type id :http-instance] http-instance))))

;; (defmethod ac/actions :adapter.type/rest
;;   [genv {:adapter/keys [type id]}]
;;   (let [{:keys [http-instance]} (get-in genv [type id])]
;;     (-> genv
;;       (assoc-in [type id :actions] (rc/actions @http-instance)))))

;; (defmethod ac/pathom-env :adapter.type/rest
;;   [genv {:adapter/keys [type id]} {:keys [operations] :or {operations []}}]
;;   (let [aenv (get-in genv [type id])]
;;     (->> operations
;;       (ops/generate aenv)
;;       (pci/register genv))))

;; (comment

;;   (require '[com.vadelabs.datasource-workos.interface])
;;   (require '[com.vadelabs.datasource-openai.interface])
;;   (require '[com.vadelabs.utils-core.interface :as uc])

;;   (def workos
;;     {:adapter/id (uc/uuid ::workos)
;;      :adapter/type :adapter.type/rest
;;      :adapter/identifier :workos
;;      :adapter/nspace :workos
;;      :adapter/config {:api-key "sk_test_a2V5XzAxR1RFQkYwRjVFMlpHNERZSERIUkVSVDZFLGM2azF1UHFUb1VDdFBKUHNTSjlFdVZpVzI"
;;                       :client-id "client_01GTEBF0K6466FBHF3G6VH5FAH"}})

;;   (def openai
;;     {:adapter/id (uc/uuid ::openai)
;;      :adapter/type :adapter.type/rest
;;      :adapter/identifier :openai
;;      :adapter/nspace :openai
;;      :adapter/config {:api-key "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"
;;                       :organization "org-0CrfE6SMqBnSopQvfLWl6p75"}})

;;   (ac/initialize {:parser `parser}
;;     [workos openai])

;;   :rcf)

==> adapters-2023.04.27-696.jar: com/vadelabs/adapter_rest/interface.clj <==
(ns com.vadelabs.adapter-rest.interface
  (:require
   [com.vadelabs.adapter-core.interface :as ac]
   [com.vadelabs.adapter-rest.pathom :as pathom]
   [com.vadelabs.datasource-core.interface :as dc]
   [com.vadelabs.utils-core.interface :as uc]
   [com.wsscode.pathom3.connect.indexes :as pci]))

(defmethod ac/initiate-env! :adapter.type/rest
  [genv {:adapter/keys [type id]}]
  (let [aenv (get-in genv [type id])
        http-instance (dc/http-instance aenv)]
    (-> genv
      (assoc-in [type id :http-instance] http-instance))))

(defmethod ac/pathom-env :adapter.type/rest
  [genv {:adapter/keys [type id]}]
  (let [aenv (get-in genv [type id])]
    (->> aenv
      pathom/operations
      (pci/register genv))))

(comment

  :rcf)

(def adapter
  {:adapter/id (uc/uuid ::adapter)
   :adapter/nspace :rest
   :adapter/type :adapter.type/rest
   :adapter/qualify-attributes false
   :adapter/config {}})

(def datasources
  [{:datasource/id (uc/uuid ::datasource)
    :datasource/display-name "REST"
    :datasource/description "Adapter to integrate REST API"
    :datasource/slug "rest"
    :datasource/icon ""
    :datasource/preview ""
    :datasource/adapter adapter
    :datasource/attributes []
    :datasource/actions []
    :datasource/categories []
    :datasource/collections []}])

;; (defmethod ac/connect :adapter.type/rest
;;   [genv {:adapter/keys [type id]}]
;;   (let [aenv (get-in genv [type id])
;;         http-instance (delay (rc/http-instance aenv))]
;;     (-> genv
;;       (assoc-in [type id :http-instance] http-instance))))

;; (defmethod ac/actions :adapter.type/rest
;;   [genv {:adapter/keys [type id]}]
;;   (let [{:keys [http-instance]} (get-in genv [type id])]
;;     (-> genv
;;       (assoc-in [type id :actions] (rc/actions @http-instance)))))

;; (defmethod ac/pathom-env :adapter.type/rest
;;   [genv {:adapter/keys [type id]} {:keys [operations] :or {operations []}}]
;;   (let [aenv (get-in genv [type id])]
;;     (->> operations
;;       (ops/generate aenv)
;;       (pci/register genv))))

;; (comment

;;   (require '[com.vadelabs.datasource-workos.interface])
;;   (require '[com.vadelabs.datasource-openai.interface])
;;   (require '[com.vadelabs.utils-core.interface :as uc])

;;   (def workos
;;     {:adapter/id (uc/uuid ::workos)
;;      :adapter/type :adapter.type/rest
;;      :adapter/identifier :workos
;;      :adapter/nspace :workos
;;      :adapter/config {:api-key "sk_test_a2V5XzAxR1RFQkYwRjVFMlpHNERZSERIUkVSVDZFLGM2azF1UHFUb1VDdFBKUHNTSjlFdVZpVzI"
;;                       :client-id "client_01GTEBF0K6466FBHF3G6VH5FAH"}})

;;   (def openai
;;     {:adapter/id (uc/uuid ::openai)
;;      :adapter/type :adapter.type/rest
;;      :adapter/identifier :openai
;;      :adapter/nspace :openai
;;      :adapter/config {:api-key "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"
;;                       :organization "org-0CrfE6SMqBnSopQvfLWl6p75"}})

;;   (ac/initialize {:parser `parser}
;;     [workos openai])

;;   :rcf)
